@@ -1,4 +1,5 @@
-﻿define(['libraryBrowser', 'cardBuilder', 'dom', 'apphost', 'scrollStyles', 'emby-itemscontainer'], function (libraryBrowser, cardBuilder, dom, appHost) {
+﻿define(['libraryBrowser', 'cardBuilder', 'dom', 'apphost', 'imageLoader', 'scrollStyles', 'emby-itemscontainer'], function (libraryBrowser, cardBuilder, dom, appHost, imageLoader) {
+    'use strict';
 
     function enableScrollX() {
         return browserInfo.mobile && AppInfo.enableAppLayouts;
@@ -101,7 +102,7 @@
                     showParentTitle: section.showParentTitle,
                     scalable: true,
                     overlayPlayButton: section.overlayPlayButton,
-                    overlayMoreButton: section.overlayMoreButton,
+                    overlayMoreButton: section.overlayMoreButton && !cardLayout,
                     action: section.action,
                     allowBottomPadding: !enableScrollX(),
                     cardLayout: cardLayout,
@@ -112,7 +113,7 @@
             }
 
             elem.innerHTML = html;
-            ImageLoader.lazyChildren(elem);
+            imageLoader.lazyChildren(elem);
         });
     }
 
